#[non_exhaustive]pub enum ServerOrderingStrategy {
QueryStatistics,
UserProvidedOrder,
RoundRobin,
}Expand description
The strategy for establishing the query order of name servers in a pool.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
QueryStatistics
Servers are ordered based on collected query statistics. The ordering may vary over time.
UserProvidedOrder
The order provided to the resolver is used. The ordering does not vary over time.
RoundRobin
The order of servers is rotated in a round-robin fashion. This is useful for load balancing and ensuring that all servers are used evenly.