pub struct OpportunisticEncryptionPersistence {
pub path: PathBuf,
pub save_interval: Duration,
}Expand description
Configuration for persistence of opportunistic encryption probe state.
Fields
path: PathBufPath to a TOML state file that may be used for saving/loading opportunistic encryption state.
save_interval: DurationInterval after which opportunistic encryption state is periodically saved to path.