Lookup

Struct Lookup 

pub struct Lookup { /* private fields */ }
Result of a DNS query when querying for any record type supported by the Hickory DNS Proto library.

For IP resolution see LookupIp, as it has more features for A and AAAA lookups.

Implementations

Source

impl Lookup

pub fn from_rdata(query: Query, rdata: RData) -> Self

Return new instance with given rdata and the maximum TTL.

pub fn new_with_max_ttl( query: Query, answers: impl IntoIterator<Item = Record>, ) -> Self

Return new instance with given records and the maximum TTL.

pub fn new_with_deadline( query: Query, answers: impl IntoIterator<Item = Record>, valid_until: Instant, ) -> Self

Return a new instance with the given records and deadline.

pub fn query(&self) -> &Query

Returns a reference to the Query that was used to produce this result.

pub fn message(&self) -> &Message

Returns a reference to the underlying DNS Message.

pub fn answers(&self) -> &[Record]

Returns a reference to the answer records from the message.

pub fn authorities(&self) -> &[Record]

Returns a reference to the authority records from the message.

pub fn additionals(&self) -> &[Record]

Returns a reference to the additional records from the message.

pub fn valid_until(&self) -> Instant

Returns the Instant at which this Lookup is no longer valid.