DnssecPolicyConfig

Enum DnssecPolicyConfig 

pub enum DnssecPolicyConfig {
    SecurityUnaware,
    ValidationDisabled,
    ValidateWithStaticKey {
        path: Option<PathBuf>,
        nsec3_soft_iteration_limit: Option<u16>,
        nsec3_hard_iteration_limit: Option<u16>,
        validation_cache_size: Option<usize>,
    },
}
Available on crate features recursor and serde only.
DNSSEC policy configuration

Variants



SecurityUnaware

security unaware; DNSSEC records will not be requested nor processed



ValidationDisabled

Available on crate feature __dnssec only.

DNSSEC validation is disabled; DNSSEC records will be requested and processed



ValidateWithStaticKey

Available on crate feature __dnssec only.

DNSSEC validation is enabled and will use the chosen trust_anchor set of keys

Fields

path: Option<PathBuf>

set to None to use built-in trust anchor

nsec3_soft_iteration_limit: Option<u16>

set to control the ‘soft’ NSEC3 iteration limit. Responses where valid NSEC3 records are returned having an iteration count above this limit, but below the hard limit, will be considered insecure (answered without the AD bit set.)

nsec3_hard_iteration_limit: Option<u16>

set to control the ‘hard’ NSEC3 iteration limit. Responses where valid NSEC3 records are returned having an iteration count above this limit will be considered Bogus and will result in a SERVFAIL response being returned to the requester.

validation_cache_size: Option<usize>

set to control the size of the DNSSEC validation cache. Set to none to use the default