#[non_exhaustive]pub struct DnssecConfig {
pub trust_anchor: Option<Arc<TrustAnchors>>,
pub nsec3_soft_iteration_limit: Option<u16>,
pub nsec3_hard_iteration_limit: Option<u16>,
pub validation_cache_size: Option<usize>,
}Available on crate features
__dnssec and recursor only.Expand description
DNSSEC configuration options for use in DnssecPolicy
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trust_anchor: Option<Arc<TrustAnchors>>set to None to use built-in trust anchor
nsec3_soft_iteration_limit: Option<u16>NSEC3 soft iteration limit. Responses with NSEC3 records having an iteration count exceeding this value, but less than the hard limit, will return Proof::Insecure
nsec3_hard_iteration_limit: Option<u16>NSEC3 hard iteration limit. Responses with NSEC3 responses having an iteration count exceeding this value will return Proof::Bogus
validation_cache_size: Option<usize>Validation cache size. Controls how many DNSSEC validations are cached for future use.