pub struct RecursorOptions {Show 13 fields
pub ns_cache_size: usize,
pub response_cache_size: u64,
pub recursion_limit: u8,
pub ns_recursion_limit: u8,
pub allow_answers: Vec<IpNet>,
pub deny_answers: Vec<IpNet>,
pub allow_server: Vec<IpNet>,
pub deny_server: Vec<IpNet>,
pub avoid_local_udp_ports: HashSet<u16>,
pub cache_policy: TtlConfig,
pub case_randomization: bool,
pub opportunistic_encryption: OpportunisticEncryption,
pub edns_payload_len: u16,
}recursor only.Expand description
Options for the Recursor
Fields
ns_cache_size: usizeMaximum nameserver cache size
response_cache_size: u64Maximum DNS response cache size
recursion_limit: u8Maximum recursion depth for queries
Setting to 0 will fail all requests requiring recursion.
ns_recursion_limit: u8Maximum recursion depth for building NS pools
Setting to 0 will fail all requests requiring recursion.
allow_answers: Vec<IpNet>Networks that will not be filtered from responses. This overrides anything present in deny_answers
deny_answers: Vec<IpNet>Networks that will be filtered from responses
allow_server: Vec<IpNet>Networks that will be queried during resolution
deny_server: Vec<IpNet>Networks that will not be queried during resolution
avoid_local_udp_ports: HashSet<u16>Local UDP ports to avoid when making outgoing queries
cache_policy: TtlConfigCaching policy, setting minimum and maximum TTLs
case_randomization: boolEnable case randomization.
Randomize the case of letters in query names, and require that responses preserve the case of the query name, in order to mitigate spoofing attacks. This is only applied over UDP.
This implements the mechanism described in draft-vixie-dnsext-dns0x20-00.
opportunistic_encryption: OpportunisticEncryptionConfigure RFC 9539 opportunistic encryption.
edns_payload_len: u16Configure the EDNS UDP payload size used in queries.