NameServer

Struct NameServer 

pub struct NameServer<P: ConnectionProvider> { /* private fields */ }
A remote DNS server, identified by its IP address.

This potentially holds multiple open connections to the server, according to the configured protocols, and will make new connections as needed.

Implementations

Source

impl<P: ConnectionProvider> NameServer<P>

pub fn new( connections: impl IntoIterator<Item = (Protocol, P::Conn)>, config: NameServerConfig, options: &ResolverOpts, connection_provider: P, ) -> Self

Create a new NameServer with the given connections and configuration.

The connections will usually be empty.