pub struct OpportunisticEncryptionStatePersistTask<T> { /* private fields */ }Available on crate feature
toml and (crate features __tls or __quic) only.Expand description
A background task for periodically saving opportunistic encryption state.
Implementations
Sourceimpl<T: Time> OpportunisticEncryptionStatePersistTask<T>
impl<T: Time> OpportunisticEncryptionStatePersistTask<T>
Sourcepub async fn start<P: RuntimeProvider>(
config: OpportunisticEncryptionPersistence,
pool_context: &Arc<PoolContext>,
conn_provider: P,
) -> Result<Option<P::Handle>, String>
pub async fn start<P: RuntimeProvider>( config: OpportunisticEncryptionPersistence, pool_context: &Arc<PoolContext>, conn_provider: P, ) -> Result<Option<P::Handle>, String>
Starts the persistence task based on the given configuration.