pub struct TlsConfig {
pub config: ClientConfig,
}Expand description
TLS configuration for the connection provider.
Fields
config: ClientConfigAvailable on crate feature
__tls only.The TLS configuration to use for secure connections.
Implementations
Sourceimpl TlsConfig
impl TlsConfig
Sourcepub fn insecure_skip_verify(&mut self)
Available on crate feature __tls only.
pub fn insecure_skip_verify(&mut self)
__tls only.Disable certificate verification.
This is typically unsafe and insecure, except in the context of RFC 9539 opportunistic encryption which requires the peer certificate not be verified.