pub struct Lookup { /* private fields */ }Expand description
Result of a DNS query when querying for any record type supported by the Hickory DNS Proto library.
For IP resolution see LookupIp, as it has more features for A and AAAA lookups.
Implementations
Sourceimpl Lookup
impl Lookup
Sourcepub fn from_rdata(query: Query, rdata: RData) -> Self
pub fn from_rdata(query: Query, rdata: RData) -> Self
Return new instance with given rdata and the maximum TTL.
Sourcepub fn new_with_max_ttl(
query: Query,
answers: impl IntoIterator<Item = Record>,
) -> Self
pub fn new_with_max_ttl( query: Query, answers: impl IntoIterator<Item = Record>, ) -> Self
Return new instance with given records and the maximum TTL.
Sourcepub fn new_with_deadline(
query: Query,
answers: impl IntoIterator<Item = Record>,
valid_until: Instant,
) -> Self
pub fn new_with_deadline( query: Query, answers: impl IntoIterator<Item = Record>, valid_until: Instant, ) -> Self
Return a new instance with the given records and deadline.
Sourcepub fn query(&self) -> &Query
pub fn query(&self) -> &Query
Returns a reference to the Query that was used to produce this result.
Returns a reference to the authority records from the message.
Sourcepub fn additionals(&self) -> &[Record]
pub fn additionals(&self) -> &[Record]
Returns a reference to the additional records from the message.
Sourcepub fn valid_until(&self) -> Instant
pub fn valid_until(&self) -> Instant
Returns the Instant at which this Lookup is no longer valid.