#[non_exhaustive]pub enum RecursorError {
MaxRecordLimitExceeded {
count: usize,
record_type: RecordType,
},
Message(&'static str),
Msg(String),
Negative(AuthorityData),
ForwardNS(Arc<[ForwardNSData]>),
Io(Error),
Net(NetError),
Timeout,
RecursionLimitExceeded {
count: usize,
},
}recursor only.Expand description
The error kind for errors that get returned in the crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
MaxRecordLimitExceeded
Maximum record limit was exceeded
Fields
record_type: RecordTypeThe record type that triggered the error.
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
Msg(String)
An error with an arbitrary message, stored as String
Negative(AuthorityData)
Upstream DNS authority returned an empty RRset
ForwardNS(Arc<[ForwardNSData]>)
Upstream DNS authority returned a referral to another set of nameservers in the form of additional NS records.
Io(Error)
An error got returned from IO
Net(NetError)
An error got returned by the hickory-proto crate
Timeout
A request timed out
RecursionLimitExceeded
Could not fetch all records because a recursion limit was exceeded
Implementations
Sourceimpl RecursorError
impl RecursorError
Sourcepub fn recursion_exceeded(limit: u8, depth: u8, name: &Name) -> Result<(), Self>
pub fn recursion_exceeded(limit: u8, depth: u8, name: &Name) -> Result<(), Self>
Test if the recursion depth has been exceeded, and return an error if it has.
Sourcepub fn into_soa(self) -> Option<Box<Record<SOA>>>
pub fn into_soa(self) -> Option<Box<Record<SOA>>>
Returns the SOA record, if the error contains one
Sourcepub fn is_no_records_found(&self) -> bool
pub fn is_no_records_found(&self) -> bool
Returns true if no records were returned
Sourcepub fn is_nx_domain(&self) -> bool
pub fn is_nx_domain(&self) -> bool
Returns true if the domain does not exist
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if a query timed out