pub struct NameServer<P: ConnectionProvider> { /* private fields */ }Expand description
A remote DNS server, identified by its IP address.
This potentially holds multiple open connections to the server, according to the configured protocols, and will make new connections as needed.
Implementations
Sourceimpl<P: ConnectionProvider> NameServer<P>
impl<P: ConnectionProvider> NameServer<P>
Sourcepub fn new(
connections: impl IntoIterator<Item = (Protocol, P::Conn)>,
config: NameServerConfig,
options: &ResolverOpts,
connection_provider: P,
) -> Self
pub fn new( connections: impl IntoIterator<Item = (Protocol, P::Conn)>, config: NameServerConfig, options: &ResolverOpts, connection_provider: P, ) -> Self
Create a new NameServer with the given connections and configuration.
The connections will usually be empty.