ResolverBuilder

Struct ResolverBuilder 

pub struct ResolverBuilder<P> { /* private fields */ }
A builder to construct a Resolver.

Created by Resolver::builder.

Implementations

Source

impl<P: ConnectionProvider> ResolverBuilder<P>

pub fn with_options(self, options: ResolverOpts) -> Self

Sets the ResolverOpts to be used by the resolver.

NB: A ResolverBuilder<P> will use the system configuration e.g., resolv.conf, by default. Usage of this method will overwrite any options set by the system configuration.

See system_conf for functions that can parse a ResolverOpts from the system configuration, or use options_mut() to acquire a muitable reference to the existing ResolverOpts.

pub fn options_mut(&mut self) -> &mut ResolverOpts

Returns a mutable reference to the ResolverOpts.

pub fn with_trust_anchor(self, trust_anchor: Arc<TrustAnchors>) -> Self

Available on crate feature __dnssec only.

Set the DNSSEC trust anchors to be used by the resolver.

pub fn with_tls_config(self, config: ClientConfig) -> Self

Available on crate feature __tls only.

Set the TLS configuration to be used by the resolver.

pub fn with_opportunistic_encryption( self, opportunistic_encryption: OpportunisticEncryption, ) -> Self

Set the opportunistic encryption configuration to be used by the resolver.

pub fn with_encrypted_transport_state( self, encrypted_transport_state: NameServerTransportState, ) -> Self

Set pre-existing encrypted transport state for use with opportunistic encryption.

pub fn nsec3_iteration_limits( self, soft_limit: Option<u16>, hard_limit: Option<u16>, ) -> Self

Available on crate feature __dnssec only.

Set maximum limits on NSEC3 additional iterations.

See RFC 9276. Signed zones that exceed the soft limit will be treated as insecure, and signed zones that exceed the hard limit will be treated as bogus.

pub fn build(self) -> Result<Resolver<P>, NetError>

Construct the resolver.